# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pycherwell.configuration import Configuration


class FieldDefinition(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'auto_fill': 'bool',
        'calculated': 'bool',
        'category': 'str',
        'decimal_digits': 'int',
        'description': 'str',
        'details': 'str',
        'display_name': 'str',
        'enabled': 'bool',
        'field_id': 'str',
        'has_date': 'bool',
        'has_time': 'bool',
        'is_full_text_searchable': 'bool',
        'maximum_size': 'str',
        'name': 'str',
        'read_only': 'bool',
        'required': 'bool',
        'type': 'str',
        'type_localized': 'str',
        'validated': 'bool',
        'whole_digits': 'int'
    }

    attribute_map = {
        'auto_fill': 'autoFill',
        'calculated': 'calculated',
        'category': 'category',
        'decimal_digits': 'decimalDigits',
        'description': 'description',
        'details': 'details',
        'display_name': 'displayName',
        'enabled': 'enabled',
        'field_id': 'fieldId',
        'has_date': 'hasDate',
        'has_time': 'hasTime',
        'is_full_text_searchable': 'isFullTextSearchable',
        'maximum_size': 'maximumSize',
        'name': 'name',
        'read_only': 'readOnly',
        'required': 'required',
        'type': 'type',
        'type_localized': 'typeLocalized',
        'validated': 'validated',
        'whole_digits': 'wholeDigits'
    }

    def __init__(self, auto_fill=None, calculated=None, category=None, decimal_digits=None, description=None, details=None, display_name=None, enabled=None, field_id=None, has_date=None, has_time=None, is_full_text_searchable=None, maximum_size=None, name=None, read_only=None, required=None, type=None, type_localized=None, validated=None, whole_digits=None, local_vars_configuration=None):  # noqa: E501
        """FieldDefinition - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._auto_fill = None
        self._calculated = None
        self._category = None
        self._decimal_digits = None
        self._description = None
        self._details = None
        self._display_name = None
        self._enabled = None
        self._field_id = None
        self._has_date = None
        self._has_time = None
        self._is_full_text_searchable = None
        self._maximum_size = None
        self._name = None
        self._read_only = None
        self._required = None
        self._type = None
        self._type_localized = None
        self._validated = None
        self._whole_digits = None
        self.discriminator = None

        if auto_fill is not None:
            self.auto_fill = auto_fill
        if calculated is not None:
            self.calculated = calculated
        if category is not None:
            self.category = category
        if decimal_digits is not None:
            self.decimal_digits = decimal_digits
        if description is not None:
            self.description = description
        if details is not None:
            self.details = details
        if display_name is not None:
            self.display_name = display_name
        if enabled is not None:
            self.enabled = enabled
        if field_id is not None:
            self.field_id = field_id
        if has_date is not None:
            self.has_date = has_date
        if has_time is not None:
            self.has_time = has_time
        if is_full_text_searchable is not None:
            self.is_full_text_searchable = is_full_text_searchable
        if maximum_size is not None:
            self.maximum_size = maximum_size
        if name is not None:
            self.name = name
        if read_only is not None:
            self.read_only = read_only
        if required is not None:
            self.required = required
        if type is not None:
            self.type = type
        if type_localized is not None:
            self.type_localized = type_localized
        if validated is not None:
            self.validated = validated
        if whole_digits is not None:
            self.whole_digits = whole_digits

    @property
    def auto_fill(self):
        """Gets the auto_fill of this FieldDefinition.  # noqa: E501


        :return: The auto_fill of this FieldDefinition.  # noqa: E501
        :rtype: bool
        """
        return self._auto_fill

    @auto_fill.setter
    def auto_fill(self, auto_fill):
        """Sets the auto_fill of this FieldDefinition.


        :param auto_fill: The auto_fill of this FieldDefinition.  # noqa: E501
        :type: bool
        """

        self._auto_fill = auto_fill

    @property
    def calculated(self):
        """Gets the calculated of this FieldDefinition.  # noqa: E501


        :return: The calculated of this FieldDefinition.  # noqa: E501
        :rtype: bool
        """
        return self._calculated

    @calculated.setter
    def calculated(self, calculated):
        """Sets the calculated of this FieldDefinition.


        :param calculated: The calculated of this FieldDefinition.  # noqa: E501
        :type: bool
        """

        self._calculated = calculated

    @property
    def category(self):
        """Gets the category of this FieldDefinition.  # noqa: E501


        :return: The category of this FieldDefinition.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this FieldDefinition.


        :param category: The category of this FieldDefinition.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def decimal_digits(self):
        """Gets the decimal_digits of this FieldDefinition.  # noqa: E501


        :return: The decimal_digits of this FieldDefinition.  # noqa: E501
        :rtype: int
        """
        return self._decimal_digits

    @decimal_digits.setter
    def decimal_digits(self, decimal_digits):
        """Sets the decimal_digits of this FieldDefinition.


        :param decimal_digits: The decimal_digits of this FieldDefinition.  # noqa: E501
        :type: int
        """

        self._decimal_digits = decimal_digits

    @property
    def description(self):
        """Gets the description of this FieldDefinition.  # noqa: E501


        :return: The description of this FieldDefinition.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this FieldDefinition.


        :param description: The description of this FieldDefinition.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def details(self):
        """Gets the details of this FieldDefinition.  # noqa: E501


        :return: The details of this FieldDefinition.  # noqa: E501
        :rtype: str
        """
        return self._details

    @details.setter
    def details(self, details):
        """Sets the details of this FieldDefinition.


        :param details: The details of this FieldDefinition.  # noqa: E501
        :type: str
        """

        self._details = details

    @property
    def display_name(self):
        """Gets the display_name of this FieldDefinition.  # noqa: E501


        :return: The display_name of this FieldDefinition.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this FieldDefinition.


        :param display_name: The display_name of this FieldDefinition.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def enabled(self):
        """Gets the enabled of this FieldDefinition.  # noqa: E501


        :return: The enabled of this FieldDefinition.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this FieldDefinition.


        :param enabled: The enabled of this FieldDefinition.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def field_id(self):
        """Gets the field_id of this FieldDefinition.  # noqa: E501


        :return: The field_id of this FieldDefinition.  # noqa: E501
        :rtype: str
        """
        return self._field_id

    @field_id.setter
    def field_id(self, field_id):
        """Sets the field_id of this FieldDefinition.


        :param field_id: The field_id of this FieldDefinition.  # noqa: E501
        :type: str
        """

        self._field_id = field_id

    @property
    def has_date(self):
        """Gets the has_date of this FieldDefinition.  # noqa: E501


        :return: The has_date of this FieldDefinition.  # noqa: E501
        :rtype: bool
        """
        return self._has_date

    @has_date.setter
    def has_date(self, has_date):
        """Sets the has_date of this FieldDefinition.


        :param has_date: The has_date of this FieldDefinition.  # noqa: E501
        :type: bool
        """

        self._has_date = has_date

    @property
    def has_time(self):
        """Gets the has_time of this FieldDefinition.  # noqa: E501


        :return: The has_time of this FieldDefinition.  # noqa: E501
        :rtype: bool
        """
        return self._has_time

    @has_time.setter
    def has_time(self, has_time):
        """Sets the has_time of this FieldDefinition.


        :param has_time: The has_time of this FieldDefinition.  # noqa: E501
        :type: bool
        """

        self._has_time = has_time

    @property
    def is_full_text_searchable(self):
        """Gets the is_full_text_searchable of this FieldDefinition.  # noqa: E501


        :return: The is_full_text_searchable of this FieldDefinition.  # noqa: E501
        :rtype: bool
        """
        return self._is_full_text_searchable

    @is_full_text_searchable.setter
    def is_full_text_searchable(self, is_full_text_searchable):
        """Sets the is_full_text_searchable of this FieldDefinition.


        :param is_full_text_searchable: The is_full_text_searchable of this FieldDefinition.  # noqa: E501
        :type: bool
        """

        self._is_full_text_searchable = is_full_text_searchable

    @property
    def maximum_size(self):
        """Gets the maximum_size of this FieldDefinition.  # noqa: E501


        :return: The maximum_size of this FieldDefinition.  # noqa: E501
        :rtype: str
        """
        return self._maximum_size

    @maximum_size.setter
    def maximum_size(self, maximum_size):
        """Sets the maximum_size of this FieldDefinition.


        :param maximum_size: The maximum_size of this FieldDefinition.  # noqa: E501
        :type: str
        """

        self._maximum_size = maximum_size

    @property
    def name(self):
        """Gets the name of this FieldDefinition.  # noqa: E501


        :return: The name of this FieldDefinition.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this FieldDefinition.


        :param name: The name of this FieldDefinition.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def read_only(self):
        """Gets the read_only of this FieldDefinition.  # noqa: E501


        :return: The read_only of this FieldDefinition.  # noqa: E501
        :rtype: bool
        """
        return self._read_only

    @read_only.setter
    def read_only(self, read_only):
        """Sets the read_only of this FieldDefinition.


        :param read_only: The read_only of this FieldDefinition.  # noqa: E501
        :type: bool
        """

        self._read_only = read_only

    @property
    def required(self):
        """Gets the required of this FieldDefinition.  # noqa: E501


        :return: The required of this FieldDefinition.  # noqa: E501
        :rtype: bool
        """
        return self._required

    @required.setter
    def required(self, required):
        """Sets the required of this FieldDefinition.


        :param required: The required of this FieldDefinition.  # noqa: E501
        :type: bool
        """

        self._required = required

    @property
    def type(self):
        """Gets the type of this FieldDefinition.  # noqa: E501


        :return: The type of this FieldDefinition.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this FieldDefinition.


        :param type: The type of this FieldDefinition.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def type_localized(self):
        """Gets the type_localized of this FieldDefinition.  # noqa: E501


        :return: The type_localized of this FieldDefinition.  # noqa: E501
        :rtype: str
        """
        return self._type_localized

    @type_localized.setter
    def type_localized(self, type_localized):
        """Sets the type_localized of this FieldDefinition.


        :param type_localized: The type_localized of this FieldDefinition.  # noqa: E501
        :type: str
        """

        self._type_localized = type_localized

    @property
    def validated(self):
        """Gets the validated of this FieldDefinition.  # noqa: E501


        :return: The validated of this FieldDefinition.  # noqa: E501
        :rtype: bool
        """
        return self._validated

    @validated.setter
    def validated(self, validated):
        """Sets the validated of this FieldDefinition.


        :param validated: The validated of this FieldDefinition.  # noqa: E501
        :type: bool
        """

        self._validated = validated

    @property
    def whole_digits(self):
        """Gets the whole_digits of this FieldDefinition.  # noqa: E501


        :return: The whole_digits of this FieldDefinition.  # noqa: E501
        :rtype: int
        """
        return self._whole_digits

    @whole_digits.setter
    def whole_digits(self, whole_digits):
        """Sets the whole_digits of this FieldDefinition.


        :param whole_digits: The whole_digits of this FieldDefinition.  # noqa: E501
        :type: int
        """

        self._whole_digits = whole_digits

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FieldDefinition):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FieldDefinition):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pycherwell.configuration import Configuration


class SaveStoredValueRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'description': 'str',
        'folder': 'str',
        'name': 'str',
        'scope': 'str',
        'scope_owner': 'str',
        'stand_in_key': 'str',
        'stored_value_type': 'str',
        'value': 'str'
    }

    attribute_map = {
        'description': 'description',
        'folder': 'folder',
        'name': 'name',
        'scope': 'scope',
        'scope_owner': 'scopeOwner',
        'stand_in_key': 'standInKey',
        'stored_value_type': 'storedValueType',
        'value': 'value'
    }

    def __init__(self, description=None, folder=None, name=None, scope=None, scope_owner=None, stand_in_key=None, stored_value_type=None, value=None, local_vars_configuration=None):  # noqa: E501
        """SaveStoredValueRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._description = None
        self._folder = None
        self._name = None
        self._scope = None
        self._scope_owner = None
        self._stand_in_key = None
        self._stored_value_type = None
        self._value = None
        self.discriminator = None

        if description is not None:
            self.description = description
        if folder is not None:
            self.folder = folder
        if name is not None:
            self.name = name
        if scope is not None:
            self.scope = scope
        if scope_owner is not None:
            self.scope_owner = scope_owner
        if stand_in_key is not None:
            self.stand_in_key = stand_in_key
        if stored_value_type is not None:
            self.stored_value_type = stored_value_type
        if value is not None:
            self.value = value

    @property
    def description(self):
        """Gets the description of this SaveStoredValueRequest.  # noqa: E501


        :return: The description of this SaveStoredValueRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this SaveStoredValueRequest.


        :param description: The description of this SaveStoredValueRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def folder(self):
        """Gets the folder of this SaveStoredValueRequest.  # noqa: E501


        :return: The folder of this SaveStoredValueRequest.  # noqa: E501
        :rtype: str
        """
        return self._folder

    @folder.setter
    def folder(self, folder):
        """Sets the folder of this SaveStoredValueRequest.


        :param folder: The folder of this SaveStoredValueRequest.  # noqa: E501
        :type: str
        """

        self._folder = folder

    @property
    def name(self):
        """Gets the name of this SaveStoredValueRequest.  # noqa: E501


        :return: The name of this SaveStoredValueRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SaveStoredValueRequest.


        :param name: The name of this SaveStoredValueRequest.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def scope(self):
        """Gets the scope of this SaveStoredValueRequest.  # noqa: E501


        :return: The scope of this SaveStoredValueRequest.  # noqa: E501
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this SaveStoredValueRequest.


        :param scope: The scope of this SaveStoredValueRequest.  # noqa: E501
        :type: str
        """

        self._scope = scope

    @property
    def scope_owner(self):
        """Gets the scope_owner of this SaveStoredValueRequest.  # noqa: E501


        :return: The scope_owner of this SaveStoredValueRequest.  # noqa: E501
        :rtype: str
        """
        return self._scope_owner

    @scope_owner.setter
    def scope_owner(self, scope_owner):
        """Sets the scope_owner of this SaveStoredValueRequest.


        :param scope_owner: The scope_owner of this SaveStoredValueRequest.  # noqa: E501
        :type: str
        """

        self._scope_owner = scope_owner

    @property
    def stand_in_key(self):
        """Gets the stand_in_key of this SaveStoredValueRequest.  # noqa: E501


        :return: The stand_in_key of this SaveStoredValueRequest.  # noqa: E501
        :rtype: str
        """
        return self._stand_in_key

    @stand_in_key.setter
    def stand_in_key(self, stand_in_key):
        """Sets the stand_in_key of this SaveStoredValueRequest.


        :param stand_in_key: The stand_in_key of this SaveStoredValueRequest.  # noqa: E501
        :type: str
        """

        self._stand_in_key = stand_in_key

    @property
    def stored_value_type(self):
        """Gets the stored_value_type of this SaveStoredValueRequest.  # noqa: E501


        :return: The stored_value_type of this SaveStoredValueRequest.  # noqa: E501
        :rtype: str
        """
        return self._stored_value_type

    @stored_value_type.setter
    def stored_value_type(self, stored_value_type):
        """Sets the stored_value_type of this SaveStoredValueRequest.


        :param stored_value_type: The stored_value_type of this SaveStoredValueRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["Text", "Number", "DateTime", "Logical", "Color", "Json", "JsonArray", "Xml", "XmlCollection"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and stored_value_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `stored_value_type` ({0}), must be one of {1}"  # noqa: E501
                .format(stored_value_type, allowed_values)
            )

        self._stored_value_type = stored_value_type

    @property
    def value(self):
        """Gets the value of this SaveStoredValueRequest.  # noqa: E501


        :return: The value of this SaveStoredValueRequest.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this SaveStoredValueRequest.


        :param value: The value of this SaveStoredValueRequest.  # noqa: E501
        :type: str
        """

        self._value = value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SaveStoredValueRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SaveStoredValueRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from pycherwell.api_client import ApiClient
from pycherwell.exceptions import (
    ApiTypeError,
    ApiValueError
)


class SecurityApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def security_get_client_security_settings_v1(self, applicationtype, **kwargs):  # noqa: E501
        """Get client security settings  # noqa: E501

        Operation to get the configured client security settings. Returns true if internal, Windows, LDAP, or SAML are enabled as authentication methods.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_client_security_settings_v1(applicationtype, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str applicationtype: The type of CSM application to return security settings for.  Application type is Desktop Client, Browser Client, Browser Portal or Cherwell Mobile. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ClientSecuritySettingsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.security_get_client_security_settings_v1_with_http_info(applicationtype, **kwargs)  # noqa: E501

    def security_get_client_security_settings_v1_with_http_info(self, applicationtype, **kwargs):  # noqa: E501
        """Get client security settings  # noqa: E501

        Operation to get the configured client security settings. Returns true if internal, Windows, LDAP, or SAML are enabled as authentication methods.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_client_security_settings_v1_with_http_info(applicationtype, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str applicationtype: The type of CSM application to return security settings for.  Application type is Desktop Client, Browser Client, Browser Portal or Cherwell Mobile. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ClientSecuritySettingsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['applicationtype']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method security_get_client_security_settings_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'applicationtype' is set
        if self.api_client.client_side_validation and ('applicationtype' not in local_var_params or  # noqa: E501
                                                        local_var_params['applicationtype'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `applicationtype` when calling `security_get_client_security_settings_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'applicationtype' in local_var_params:
            path_params['applicationtype'] = local_var_params['applicationtype']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getclientsecuritysettings/applicationtype/{applicationtype}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ClientSecuritySettingsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def security_get_roles_v1(self, **kwargs):  # noqa: E501
        """Get all available Roles  # noqa: E501

        Operation to get all available Roles.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_roles_v1(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: RoleReadResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.security_get_roles_v1_with_http_info(**kwargs)  # noqa: E501

    def security_get_roles_v1_with_http_info(self, **kwargs):  # noqa: E501
        """Get all available Roles  # noqa: E501

        Operation to get all available Roles.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_roles_v1_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(RoleReadResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method security_get_roles_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getroles', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RoleReadResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def security_get_roles_v2(self, **kwargs):  # noqa: E501
        """Get all available Roles  # noqa: E501

        Operation to get all available Roles.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_roles_v2(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: RoleReadV2Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.security_get_roles_v2_with_http_info(**kwargs)  # noqa: E501

    def security_get_roles_v2_with_http_info(self, **kwargs):  # noqa: E501
        """Get all available Roles  # noqa: E501

        Operation to get all available Roles.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_roles_v2_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(RoleReadV2Response, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method security_get_roles_v2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V2/getroles', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RoleReadV2Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def security_get_security_group_business_object_permissions_by_bus_ob_id_v1(self, groupid, bus_ob_id, **kwargs):  # noqa: E501
        """Get Business Object permissions by Security Group  # noqa: E501

        Operation to get specific Business Object permissions for a Security Group.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_business_object_permissions_by_bus_ob_id_v1(groupid, bus_ob_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str groupid: Specify the Security Group ID.  (required)
        :param str bus_ob_id: Specify the Business Object ID. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[BusinessObjectPermission]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.security_get_security_group_business_object_permissions_by_bus_ob_id_v1_with_http_info(groupid, bus_ob_id, **kwargs)  # noqa: E501

    def security_get_security_group_business_object_permissions_by_bus_ob_id_v1_with_http_info(self, groupid, bus_ob_id, **kwargs):  # noqa: E501
        """Get Business Object permissions by Security Group  # noqa: E501

        Operation to get specific Business Object permissions for a Security Group.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_business_object_permissions_by_bus_ob_id_v1_with_http_info(groupid, bus_ob_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str groupid: Specify the Security Group ID.  (required)
        :param str bus_ob_id: Specify the Business Object ID. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[BusinessObjectPermission], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['groupid', 'bus_ob_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method security_get_security_group_business_object_permissions_by_bus_ob_id_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'groupid' is set
        if self.api_client.client_side_validation and ('groupid' not in local_var_params or  # noqa: E501
                                                        local_var_params['groupid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `groupid` when calling `security_get_security_group_business_object_permissions_by_bus_ob_id_v1`")  # noqa: E501
        # verify the required parameter 'bus_ob_id' is set
        if self.api_client.client_side_validation and ('bus_ob_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['bus_ob_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `bus_ob_id` when calling `security_get_security_group_business_object_permissions_by_bus_ob_id_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'groupid' in local_var_params:
            path_params['groupid'] = local_var_params['groupid']  # noqa: E501
        if 'bus_ob_id' in local_var_params:
            path_params['busObId'] = local_var_params['bus_ob_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getsecuritygroupbusinessobjectpermissions/groupid/{groupid}/busobid/{busObId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[BusinessObjectPermission]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def security_get_security_group_business_object_permissions_by_bus_ob_id_v2(self, groupid, bus_ob_id, **kwargs):  # noqa: E501
        """Get Business Object permissions by Security Group  # noqa: E501

        Operation to get specific Business Object permissions for a Security Group.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_business_object_permissions_by_bus_ob_id_v2(groupid, bus_ob_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str groupid: Specify the Security Group ID.  (required)
        :param str bus_ob_id: Specify the Business Object ID. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: GetSecurityGroupBusinessObjectPermissionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.security_get_security_group_business_object_permissions_by_bus_ob_id_v2_with_http_info(groupid, bus_ob_id, **kwargs)  # noqa: E501

    def security_get_security_group_business_object_permissions_by_bus_ob_id_v2_with_http_info(self, groupid, bus_ob_id, **kwargs):  # noqa: E501
        """Get Business Object permissions by Security Group  # noqa: E501

        Operation to get specific Business Object permissions for a Security Group.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_business_object_permissions_by_bus_ob_id_v2_with_http_info(groupid, bus_ob_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str groupid: Specify the Security Group ID.  (required)
        :param str bus_ob_id: Specify the Business Object ID. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(GetSecurityGroupBusinessObjectPermissionsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['groupid', 'bus_ob_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method security_get_security_group_business_object_permissions_by_bus_ob_id_v2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'groupid' is set
        if self.api_client.client_side_validation and ('groupid' not in local_var_params or  # noqa: E501
                                                        local_var_params['groupid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `groupid` when calling `security_get_security_group_business_object_permissions_by_bus_ob_id_v2`")  # noqa: E501
        # verify the required parameter 'bus_ob_id' is set
        if self.api_client.client_side_validation and ('bus_ob_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['bus_ob_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `bus_ob_id` when calling `security_get_security_group_business_object_permissions_by_bus_ob_id_v2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'groupid' in local_var_params:
            path_params['groupid'] = local_var_params['groupid']  # noqa: E501
        if 'bus_ob_id' in local_var_params:
            path_params['busObId'] = local_var_params['bus_ob_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V2/getsecuritygroupbusinessobjectpermissions/groupid/{groupid}/busobid/{busObId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetSecurityGroupBusinessObjectPermissionsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def security_get_security_group_business_object_permissions_by_bus_ob_name_v1(self, groupname, busobname, **kwargs):  # noqa: E501
        """Get Business Object permissions by Security Group  # noqa: E501

        Operation to get specific Business Object permissions for a Security Group.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_business_object_permissions_by_bus_ob_name_v1(groupname, busobname, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str groupname: Specify the Security Group name.  (required)
        :param str busobname: Specify the Business Object name. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[BusinessObjectPermission]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.security_get_security_group_business_object_permissions_by_bus_ob_name_v1_with_http_info(groupname, busobname, **kwargs)  # noqa: E501

    def security_get_security_group_business_object_permissions_by_bus_ob_name_v1_with_http_info(self, groupname, busobname, **kwargs):  # noqa: E501
        """Get Business Object permissions by Security Group  # noqa: E501

        Operation to get specific Business Object permissions for a Security Group.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_business_object_permissions_by_bus_ob_name_v1_with_http_info(groupname, busobname, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str groupname: Specify the Security Group name.  (required)
        :param str busobname: Specify the Business Object name. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[BusinessObjectPermission], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['groupname', 'busobname']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method security_get_security_group_business_object_permissions_by_bus_ob_name_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'groupname' is set
        if self.api_client.client_side_validation and ('groupname' not in local_var_params or  # noqa: E501
                                                        local_var_params['groupname'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `groupname` when calling `security_get_security_group_business_object_permissions_by_bus_ob_name_v1`")  # noqa: E501
        # verify the required parameter 'busobname' is set
        if self.api_client.client_side_validation and ('busobname' not in local_var_params or  # noqa: E501
                                                        local_var_params['busobname'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `busobname` when calling `security_get_security_group_business_object_permissions_by_bus_ob_name_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'groupname' in local_var_params:
            path_params['groupname'] = local_var_params['groupname']  # noqa: E501
        if 'busobname' in local_var_params:
            path_params['busobname'] = local_var_params['busobname']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getsecuritygroupbusinessobjectpermissions/groupname/{groupname}/busobname/{busobname}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[BusinessObjectPermission]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def security_get_security_group_business_object_permissions_by_bus_ob_name_v2(self, groupname, busobname, **kwargs):  # noqa: E501
        """Get Business Object permissions by Security Group  # noqa: E501

        Operation to get specific Business Object permissions for a Security Group.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_business_object_permissions_by_bus_ob_name_v2(groupname, busobname, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str groupname: Specify the Security Group name.  (required)
        :param str busobname: Specify the Business Object name. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: GetSecurityGroupBusinessObjectPermissionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.security_get_security_group_business_object_permissions_by_bus_ob_name_v2_with_http_info(groupname, busobname, **kwargs)  # noqa: E501

    def security_get_security_group_business_object_permissions_by_bus_ob_name_v2_with_http_info(self, groupname, busobname, **kwargs):  # noqa: E501
        """Get Business Object permissions by Security Group  # noqa: E501

        Operation to get specific Business Object permissions for a Security Group.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_business_object_permissions_by_bus_ob_name_v2_with_http_info(groupname, busobname, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str groupname: Specify the Security Group name.  (required)
        :param str busobname: Specify the Business Object name. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(GetSecurityGroupBusinessObjectPermissionsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['groupname', 'busobname']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method security_get_security_group_business_object_permissions_by_bus_ob_name_v2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'groupname' is set
        if self.api_client.client_side_validation and ('groupname' not in local_var_params or  # noqa: E501
                                                        local_var_params['groupname'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `groupname` when calling `security_get_security_group_business_object_permissions_by_bus_ob_name_v2`")  # noqa: E501
        # verify the required parameter 'busobname' is set
        if self.api_client.client_side_validation and ('busobname' not in local_var_params or  # noqa: E501
                                                        local_var_params['busobname'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `busobname` when calling `security_get_security_group_business_object_permissions_by_bus_ob_name_v2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'groupname' in local_var_params:
            path_params['groupname'] = local_var_params['groupname']  # noqa: E501
        if 'busobname' in local_var_params:
            path_params['busobname'] = local_var_params['busobname']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V2/getsecuritygroupbusinessobjectpermissions/groupname/{groupname}/busobname/{busobname}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetSecurityGroupBusinessObjectPermissionsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_id_v1(self, bus_ob_id, **kwargs):  # noqa: E501
        """Get Business Object permission for current user  # noqa: E501

        Operation to get Business Object permissions for the currently logged-in user's Security Group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_id_v1(bus_ob_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str bus_ob_id: Specify the Business Object ID. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[BusinessObjectPermission]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_id_v1_with_http_info(bus_ob_id, **kwargs)  # noqa: E501

    def security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_id_v1_with_http_info(self, bus_ob_id, **kwargs):  # noqa: E501
        """Get Business Object permission for current user  # noqa: E501

        Operation to get Business Object permissions for the currently logged-in user's Security Group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_id_v1_with_http_info(bus_ob_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str bus_ob_id: Specify the Business Object ID. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[BusinessObjectPermission], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['bus_ob_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_id_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'bus_ob_id' is set
        if self.api_client.client_side_validation and ('bus_ob_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['bus_ob_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `bus_ob_id` when calling `security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_id_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'bus_ob_id' in local_var_params:
            path_params['busObId'] = local_var_params['bus_ob_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getsecuritygroupbusinessobjectpermissionsforcurrentuserbybusobid/busobid/{busObId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[BusinessObjectPermission]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_id_v2(self, bus_ob_id, **kwargs):  # noqa: E501
        """Get Business Object permission for current user  # noqa: E501

        Operation to get Business Object permissions for the currently logged-in user's Security Group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_id_v2(bus_ob_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str bus_ob_id: Specify the Business Object ID. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: GetSecurityGroupBusinessObjectPermissionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_id_v2_with_http_info(bus_ob_id, **kwargs)  # noqa: E501

    def security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_id_v2_with_http_info(self, bus_ob_id, **kwargs):  # noqa: E501
        """Get Business Object permission for current user  # noqa: E501

        Operation to get Business Object permissions for the currently logged-in user's Security Group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_id_v2_with_http_info(bus_ob_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str bus_ob_id: Specify the Business Object ID. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(GetSecurityGroupBusinessObjectPermissionsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['bus_ob_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_id_v2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'bus_ob_id' is set
        if self.api_client.client_side_validation and ('bus_ob_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['bus_ob_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `bus_ob_id` when calling `security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_id_v2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'bus_ob_id' in local_var_params:
            path_params['busObId'] = local_var_params['bus_ob_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V2/getsecuritygroupbusinessobjectpermissionsforcurrentuserbybusobid/busobid/{busObId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetSecurityGroupBusinessObjectPermissionsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_name_v1(self, busobname, **kwargs):  # noqa: E501
        """Get Business Object permissions for current user  # noqa: E501

        Operation to get Business Object permissions for currently logged in user's Security Group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_name_v1(busobname, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str busobname: Specify the Business Object name. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[BusinessObjectPermission]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_name_v1_with_http_info(busobname, **kwargs)  # noqa: E501

    def security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_name_v1_with_http_info(self, busobname, **kwargs):  # noqa: E501
        """Get Business Object permissions for current user  # noqa: E501

        Operation to get Business Object permissions for currently logged in user's Security Group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_name_v1_with_http_info(busobname, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str busobname: Specify the Business Object name. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[BusinessObjectPermission], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['busobname']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_name_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'busobname' is set
        if self.api_client.client_side_validation and ('busobname' not in local_var_params or  # noqa: E501
                                                        local_var_params['busobname'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `busobname` when calling `security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_name_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'busobname' in local_var_params:
            path_params['busobname'] = local_var_params['busobname']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getsecuritygroupbusinessobjectpermissionsforcurrentuserbybusobname/busobname/{busobname}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[BusinessObjectPermission]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_name_v2(self, busobname, **kwargs):  # noqa: E501
        """Get Business Object permissions for current user  # noqa: E501

        Operation to get Business Object permissions for currently logged in user's Security Group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_name_v2(busobname, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str busobname: Specify the Business Object name. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: GetSecurityGroupBusinessObjectPermissionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_name_v2_with_http_info(busobname, **kwargs)  # noqa: E501

    def security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_name_v2_with_http_info(self, busobname, **kwargs):  # noqa: E501
        """Get Business Object permissions for current user  # noqa: E501

        Operation to get Business Object permissions for currently logged in user's Security Group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_name_v2_with_http_info(busobname, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str busobname: Specify the Business Object name. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(GetSecurityGroupBusinessObjectPermissionsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['busobname']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_name_v2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'busobname' is set
        if self.api_client.client_side_validation and ('busobname' not in local_var_params or  # noqa: E501
                                                        local_var_params['busobname'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `busobname` when calling `security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_name_v2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'busobname' in local_var_params:
            path_params['busobname'] = local_var_params['busobname']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V2/getsecuritygroupbusinessobjectpermissionsforcurrentuserbybusobname/busobname/{busobname}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetSecurityGroupBusinessObjectPermissionsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def security_get_security_group_categories_v1(self, **kwargs):  # noqa: E501
        """Get all Security Group categories  # noqa: E501

        Operation to get IDs and names for all available Security Group categories.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_categories_v1(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[RightCategory]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.security_get_security_group_categories_v1_with_http_info(**kwargs)  # noqa: E501

    def security_get_security_group_categories_v1_with_http_info(self, **kwargs):  # noqa: E501
        """Get all Security Group categories  # noqa: E501

        Operation to get IDs and names for all available Security Group categories.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_categories_v1_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[RightCategory], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method security_get_security_group_categories_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getsecuritygroupcategories', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[RightCategory]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def security_get_security_group_categories_v2(self, **kwargs):  # noqa: E501
        """Get all Security Group categories  # noqa: E501

        Operation to get IDs and names for all available Security Group categories.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_categories_v2(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SecurityRightCategoriesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.security_get_security_group_categories_v2_with_http_info(**kwargs)  # noqa: E501

    def security_get_security_group_categories_v2_with_http_info(self, **kwargs):  # noqa: E501
        """Get all Security Group categories  # noqa: E501

        Operation to get IDs and names for all available Security Group categories.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_categories_v2_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SecurityRightCategoriesResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method security_get_security_group_categories_v2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V2/getsecuritygroupcategories', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SecurityRightCategoriesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def security_get_security_group_rights_by_group_id_and_category_id_v1(self, groupid, categoryid, **kwargs):  # noqa: E501
        """Get permissions for a Security Group by category  # noqa: E501

        Operation to get permissions for a Security Group by category. To get Security Group IDs, use \"Get all available Security Groups.\" To get Security Group category IDs, use \"Get all Security Group categories.\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_rights_by_group_id_and_category_id_v1(groupid, categoryid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str groupid: Specify the Security Group ID (required)
        :param str categoryid: Specify the Security Group category ID (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[Right]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.security_get_security_group_rights_by_group_id_and_category_id_v1_with_http_info(groupid, categoryid, **kwargs)  # noqa: E501

    def security_get_security_group_rights_by_group_id_and_category_id_v1_with_http_info(self, groupid, categoryid, **kwargs):  # noqa: E501
        """Get permissions for a Security Group by category  # noqa: E501

        Operation to get permissions for a Security Group by category. To get Security Group IDs, use \"Get all available Security Groups.\" To get Security Group category IDs, use \"Get all Security Group categories.\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_rights_by_group_id_and_category_id_v1_with_http_info(groupid, categoryid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str groupid: Specify the Security Group ID (required)
        :param str categoryid: Specify the Security Group category ID (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[Right], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['groupid', 'categoryid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method security_get_security_group_rights_by_group_id_and_category_id_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'groupid' is set
        if self.api_client.client_side_validation and ('groupid' not in local_var_params or  # noqa: E501
                                                        local_var_params['groupid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `groupid` when calling `security_get_security_group_rights_by_group_id_and_category_id_v1`")  # noqa: E501
        # verify the required parameter 'categoryid' is set
        if self.api_client.client_side_validation and ('categoryid' not in local_var_params or  # noqa: E501
                                                        local_var_params['categoryid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `categoryid` when calling `security_get_security_group_rights_by_group_id_and_category_id_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'groupid' in local_var_params:
            path_params['groupid'] = local_var_params['groupid']  # noqa: E501
        if 'categoryid' in local_var_params:
            path_params['categoryid'] = local_var_params['categoryid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getsecuritygrouprights/groupid/{groupid}/categoryid/{categoryid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Right]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def security_get_security_group_rights_by_group_id_and_category_id_v2(self, groupid, categoryid, **kwargs):  # noqa: E501
        """Get permissions for a Security Group by category  # noqa: E501

        Operation to get permissions for a Security Group by category. To get Security Group IDs, use \"Get all available Security Groups.\" To get Security Group category IDs, use \"Get all Security Group categories.\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_rights_by_group_id_and_category_id_v2(groupid, categoryid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str groupid: Specify the Security Group ID (required)
        :param str categoryid: Specify the Security Group category ID (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SecurityRightsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.security_get_security_group_rights_by_group_id_and_category_id_v2_with_http_info(groupid, categoryid, **kwargs)  # noqa: E501

    def security_get_security_group_rights_by_group_id_and_category_id_v2_with_http_info(self, groupid, categoryid, **kwargs):  # noqa: E501
        """Get permissions for a Security Group by category  # noqa: E501

        Operation to get permissions for a Security Group by category. To get Security Group IDs, use \"Get all available Security Groups.\" To get Security Group category IDs, use \"Get all Security Group categories.\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_rights_by_group_id_and_category_id_v2_with_http_info(groupid, categoryid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str groupid: Specify the Security Group ID (required)
        :param str categoryid: Specify the Security Group category ID (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SecurityRightsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['groupid', 'categoryid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method security_get_security_group_rights_by_group_id_and_category_id_v2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'groupid' is set
        if self.api_client.client_side_validation and ('groupid' not in local_var_params or  # noqa: E501
                                                        local_var_params['groupid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `groupid` when calling `security_get_security_group_rights_by_group_id_and_category_id_v2`")  # noqa: E501
        # verify the required parameter 'categoryid' is set
        if self.api_client.client_side_validation and ('categoryid' not in local_var_params or  # noqa: E501
                                                        local_var_params['categoryid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `categoryid` when calling `security_get_security_group_rights_by_group_id_and_category_id_v2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'groupid' in local_var_params:
            path_params['groupid'] = local_var_params['groupid']  # noqa: E501
        if 'categoryid' in local_var_params:
            path_params['categoryid'] = local_var_params['categoryid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V2/getsecuritygrouprights/groupid/{groupid}/categoryid/{categoryid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SecurityRightsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def security_get_security_group_rights_by_group_name_and_category_name_v1(self, groupname, categoryname, **kwargs):  # noqa: E501
        """Get permissions for a Security Group by category  # noqa: E501

        Operation to get permissions for a Security Group by category.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_rights_by_group_name_and_category_name_v1(groupname, categoryname, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str groupname: Specify the Security Group name. (required)
        :param str categoryname: Specify the Security Group category name. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[Right]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.security_get_security_group_rights_by_group_name_and_category_name_v1_with_http_info(groupname, categoryname, **kwargs)  # noqa: E501

    def security_get_security_group_rights_by_group_name_and_category_name_v1_with_http_info(self, groupname, categoryname, **kwargs):  # noqa: E501
        """Get permissions for a Security Group by category  # noqa: E501

        Operation to get permissions for a Security Group by category.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_rights_by_group_name_and_category_name_v1_with_http_info(groupname, categoryname, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str groupname: Specify the Security Group name. (required)
        :param str categoryname: Specify the Security Group category name. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[Right], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['groupname', 'categoryname']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method security_get_security_group_rights_by_group_name_and_category_name_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'groupname' is set
        if self.api_client.client_side_validation and ('groupname' not in local_var_params or  # noqa: E501
                                                        local_var_params['groupname'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `groupname` when calling `security_get_security_group_rights_by_group_name_and_category_name_v1`")  # noqa: E501
        # verify the required parameter 'categoryname' is set
        if self.api_client.client_side_validation and ('categoryname' not in local_var_params or  # noqa: E501
                                                        local_var_params['categoryname'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `categoryname` when calling `security_get_security_group_rights_by_group_name_and_category_name_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'groupname' in local_var_params:
            path_params['groupname'] = local_var_params['groupname']  # noqa: E501
        if 'categoryname' in local_var_params:
            path_params['categoryname'] = local_var_params['categoryname']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getsecuritygrouprights/groupname/{groupname}/categoryname/{categoryname}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Right]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def security_get_security_group_rights_by_group_name_and_category_name_v2(self, groupname, categoryname, **kwargs):  # noqa: E501
        """Get permissions for a Security Group by category  # noqa: E501

        Operation to get permissions for a Security Group by category.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_rights_by_group_name_and_category_name_v2(groupname, categoryname, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str groupname: Specify the Security Group name. (required)
        :param str categoryname: Specify the Security Group category name. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SecurityRightsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.security_get_security_group_rights_by_group_name_and_category_name_v2_with_http_info(groupname, categoryname, **kwargs)  # noqa: E501

    def security_get_security_group_rights_by_group_name_and_category_name_v2_with_http_info(self, groupname, categoryname, **kwargs):  # noqa: E501
        """Get permissions for a Security Group by category  # noqa: E501

        Operation to get permissions for a Security Group by category.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_rights_by_group_name_and_category_name_v2_with_http_info(groupname, categoryname, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str groupname: Specify the Security Group name. (required)
        :param str categoryname: Specify the Security Group category name. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SecurityRightsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['groupname', 'categoryname']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method security_get_security_group_rights_by_group_name_and_category_name_v2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'groupname' is set
        if self.api_client.client_side_validation and ('groupname' not in local_var_params or  # noqa: E501
                                                        local_var_params['groupname'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `groupname` when calling `security_get_security_group_rights_by_group_name_and_category_name_v2`")  # noqa: E501
        # verify the required parameter 'categoryname' is set
        if self.api_client.client_side_validation and ('categoryname' not in local_var_params or  # noqa: E501
                                                        local_var_params['categoryname'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `categoryname` when calling `security_get_security_group_rights_by_group_name_and_category_name_v2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'groupname' in local_var_params:
            path_params['groupname'] = local_var_params['groupname']  # noqa: E501
        if 'categoryname' in local_var_params:
            path_params['categoryname'] = local_var_params['categoryname']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V2/getsecuritygrouprights/groupname/{groupname}/categoryname/{categoryname}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SecurityRightsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def security_get_security_group_rights_for_current_user_by_category_id_v1(self, categoryid, **kwargs):  # noqa: E501
        """Get current user's permissions by Security Group category by ID  # noqa: E501

        Operation to get permissions for the current user's Security Group by category. To get Security Group category IDs, use \"Get all Security Group categories.\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_rights_for_current_user_by_category_id_v1(categoryid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str categoryid: Specify the Security Group category ID. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[Right]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.security_get_security_group_rights_for_current_user_by_category_id_v1_with_http_info(categoryid, **kwargs)  # noqa: E501

    def security_get_security_group_rights_for_current_user_by_category_id_v1_with_http_info(self, categoryid, **kwargs):  # noqa: E501
        """Get current user's permissions by Security Group category by ID  # noqa: E501

        Operation to get permissions for the current user's Security Group by category. To get Security Group category IDs, use \"Get all Security Group categories.\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_rights_for_current_user_by_category_id_v1_with_http_info(categoryid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str categoryid: Specify the Security Group category ID. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[Right], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['categoryid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method security_get_security_group_rights_for_current_user_by_category_id_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'categoryid' is set
        if self.api_client.client_side_validation and ('categoryid' not in local_var_params or  # noqa: E501
                                                        local_var_params['categoryid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `categoryid` when calling `security_get_security_group_rights_for_current_user_by_category_id_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'categoryid' in local_var_params:
            path_params['categoryid'] = local_var_params['categoryid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getsecuritygrouprightsforcurrentuserbycategoryid/categoryid/{categoryid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Right]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def security_get_security_group_rights_for_current_user_by_category_id_v2(self, categoryid, **kwargs):  # noqa: E501
        """Get current user's permissions by Security Group category by ID  # noqa: E501

        Operation to get permissions for the current user's Security Group by category. To get Security Group category IDs, use \"Get all Security Group categories.\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_rights_for_current_user_by_category_id_v2(categoryid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str categoryid: Specify the Security Group category ID. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SecurityRightsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.security_get_security_group_rights_for_current_user_by_category_id_v2_with_http_info(categoryid, **kwargs)  # noqa: E501

    def security_get_security_group_rights_for_current_user_by_category_id_v2_with_http_info(self, categoryid, **kwargs):  # noqa: E501
        """Get current user's permissions by Security Group category by ID  # noqa: E501

        Operation to get permissions for the current user's Security Group by category. To get Security Group category IDs, use \"Get all Security Group categories.\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_rights_for_current_user_by_category_id_v2_with_http_info(categoryid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str categoryid: Specify the Security Group category ID. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SecurityRightsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['categoryid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method security_get_security_group_rights_for_current_user_by_category_id_v2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'categoryid' is set
        if self.api_client.client_side_validation and ('categoryid' not in local_var_params or  # noqa: E501
                                                        local_var_params['categoryid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `categoryid` when calling `security_get_security_group_rights_for_current_user_by_category_id_v2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'categoryid' in local_var_params:
            path_params['categoryid'] = local_var_params['categoryid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V2/getsecuritygrouprightsforcurrentuserbycategoryid/categoryid/{categoryid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SecurityRightsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def security_get_security_group_rights_for_current_user_by_category_name_v1(self, categoryname, **kwargs):  # noqa: E501
        """Get current user's permissions by Security Group category by name  # noqa: E501

        Operation to get permissions for the current user's Security Group by category.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_rights_for_current_user_by_category_name_v1(categoryname, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str categoryname: Specify the Security Group category name. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[Right]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.security_get_security_group_rights_for_current_user_by_category_name_v1_with_http_info(categoryname, **kwargs)  # noqa: E501

    def security_get_security_group_rights_for_current_user_by_category_name_v1_with_http_info(self, categoryname, **kwargs):  # noqa: E501
        """Get current user's permissions by Security Group category by name  # noqa: E501

        Operation to get permissions for the current user's Security Group by category.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_rights_for_current_user_by_category_name_v1_with_http_info(categoryname, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str categoryname: Specify the Security Group category name. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[Right], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['categoryname']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method security_get_security_group_rights_for_current_user_by_category_name_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'categoryname' is set
        if self.api_client.client_side_validation and ('categoryname' not in local_var_params or  # noqa: E501
                                                        local_var_params['categoryname'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `categoryname` when calling `security_get_security_group_rights_for_current_user_by_category_name_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'categoryname' in local_var_params:
            path_params['categoryname'] = local_var_params['categoryname']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getsecuritygrouprightsforcurrentuserbycategoryname/categoryname/{categoryname}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Right]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def security_get_security_group_rights_for_current_user_by_category_name_v2(self, categoryname, **kwargs):  # noqa: E501
        """Get current user's permissions by Security Group category by name  # noqa: E501

        Operation to get permissions for the current user's Security Group by category.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_rights_for_current_user_by_category_name_v2(categoryname, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str categoryname: Specify the Security Group category name. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SecurityRightsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.security_get_security_group_rights_for_current_user_by_category_name_v2_with_http_info(categoryname, **kwargs)  # noqa: E501

    def security_get_security_group_rights_for_current_user_by_category_name_v2_with_http_info(self, categoryname, **kwargs):  # noqa: E501
        """Get current user's permissions by Security Group category by name  # noqa: E501

        Operation to get permissions for the current user's Security Group by category.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_group_rights_for_current_user_by_category_name_v2_with_http_info(categoryname, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str categoryname: Specify the Security Group category name. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SecurityRightsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['categoryname']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method security_get_security_group_rights_for_current_user_by_category_name_v2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'categoryname' is set
        if self.api_client.client_side_validation and ('categoryname' not in local_var_params or  # noqa: E501
                                                        local_var_params['categoryname'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `categoryname` when calling `security_get_security_group_rights_for_current_user_by_category_name_v2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'categoryname' in local_var_params:
            path_params['categoryname'] = local_var_params['categoryname']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V2/getsecuritygrouprightsforcurrentuserbycategoryname/categoryname/{categoryname}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SecurityRightsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def security_get_security_groups_v1(self, **kwargs):  # noqa: E501
        """Get all available Security Groups  # noqa: E501

        Operation to get IDs, names, and descriptions for all available Security Groups.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_groups_v1(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SecurityGroupResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.security_get_security_groups_v1_with_http_info(**kwargs)  # noqa: E501

    def security_get_security_groups_v1_with_http_info(self, **kwargs):  # noqa: E501
        """Get all available Security Groups  # noqa: E501

        Operation to get IDs, names, and descriptions for all available Security Groups.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_groups_v1_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SecurityGroupResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method security_get_security_groups_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getsecuritygroups', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SecurityGroupResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def security_get_security_groups_v2(self, **kwargs):  # noqa: E501
        """Get all available Security Groups  # noqa: E501

        Operation to get IDs, names, and descriptions for all available Security Groups.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_groups_v2(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SecurityGroupV2Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.security_get_security_groups_v2_with_http_info(**kwargs)  # noqa: E501

    def security_get_security_groups_v2_with_http_info(self, **kwargs):  # noqa: E501
        """Get all available Security Groups  # noqa: E501

        Operation to get IDs, names, and descriptions for all available Security Groups.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_security_groups_v2_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SecurityGroupV2Response, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method security_get_security_groups_v2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V2/getsecuritygroups', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SecurityGroupV2Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def security_get_users_in_security_group_v1(self, groupid, **kwargs):  # noqa: E501
        """Get users in a Security Group  # noqa: E501

        Operation to get the users in a specified Security Group. Use \"Get all available Security Groups\" to get Security Group record IDs.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_users_in_security_group_v1(groupid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str groupid: Specify the Security Group ID. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[User]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.security_get_users_in_security_group_v1_with_http_info(groupid, **kwargs)  # noqa: E501

    def security_get_users_in_security_group_v1_with_http_info(self, groupid, **kwargs):  # noqa: E501
        """Get users in a Security Group  # noqa: E501

        Operation to get the users in a specified Security Group. Use \"Get all available Security Groups\" to get Security Group record IDs.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_users_in_security_group_v1_with_http_info(groupid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str groupid: Specify the Security Group ID. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[User], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['groupid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method security_get_users_in_security_group_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'groupid' is set
        if self.api_client.client_side_validation and ('groupid' not in local_var_params or  # noqa: E501
                                                        local_var_params['groupid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `groupid` when calling `security_get_users_in_security_group_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'groupid' in local_var_params:
            path_params['groupid'] = local_var_params['groupid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getusersinsecuritygroup/groupid/{groupid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[User]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def security_get_users_in_security_group_v2(self, groupid, **kwargs):  # noqa: E501
        """Get users in a Security Group  # noqa: E501

        Operation to get the users in a specified Security Group. Use \"Get all available Security Groups\" to get Security Group record IDs.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_users_in_security_group_v2(groupid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str groupid: Specify the Security Group ID. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: UserReadV2Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.security_get_users_in_security_group_v2_with_http_info(groupid, **kwargs)  # noqa: E501

    def security_get_users_in_security_group_v2_with_http_info(self, groupid, **kwargs):  # noqa: E501
        """Get users in a Security Group  # noqa: E501

        Operation to get the users in a specified Security Group. Use \"Get all available Security Groups\" to get Security Group record IDs.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_get_users_in_security_group_v2_with_http_info(groupid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str groupid: Specify the Security Group ID. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(UserReadV2Response, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['groupid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method security_get_users_in_security_group_v2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'groupid' is set
        if self.api_client.client_side_validation and ('groupid' not in local_var_params or  # noqa: E501
                                                        local_var_params['groupid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `groupid` when calling `security_get_users_in_security_group_v2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'groupid' in local_var_params:
            path_params['groupid'] = local_var_params['groupid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V2/getusersinsecuritygroup/groupid/{groupid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserReadV2Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)
